@@ -1,11 +1,12 @@
 #include <stdio.h>
 #include <vmfs/vmfs.h>
+//#include <vmfs/vmfs_fs.h>
 
 vmfs_fs_t *fs;
 vmfs_dir_t *root_dir;
 
 /// open device
-static int pvmfs_fs_open(char* device){
+static int pvmfs_fs_open(char** device){
     vmfs_lvm_t *lvm;
     vmfs_flags_t flags;
 
@@ -13,24 +14,8 @@ static int pvmfs_fs_open(char* device){
     flags.packed = 0;
     flags.allow_missing_extents = 1;
 
-    //log_mesg(3, 0, 0, fs_opt.debug, "%s: device %s\n", device);
-    if (!(lvm = vmfs_lvm_create(flags))) {
-	fprintf(stderr, "Unable to create LVM structure\n");
-	return 1;
-    }
-
-    if (vmfs_lvm_add_extent(lvm, vmfs_vol_open(device, flags)) == -1) {
-	fprintf(stderr, "Unable to open device/file \"%s\".\n", device);
-	return 1;
-    }
-
-    if (!(fs = vmfs_fs_create(lvm))) {
-	fprintf(stderr, "Unable to open filesystem\n");
-	return 1;
-    }
-
-    if (vmfs_fs_open(fs) == -1) {
-	fprintf(stderr, "Unable to open volume.\n");
+    if (!(fs = vmfs_fs_open(device, flags))) {
+	fprintf(stderr, "type: Unable to open volume.\n");
 	return 1;
     }
 
@@ -59,7 +44,7 @@ int main (int argc, char **argv){
 	return 1;
     }
 
-    source=argv[1];
+    source=&argv[1];
     ret = pvmfs_fs_open(source);
     if(ret == 0){
 	fprintf(stdout, "TYPE=\"vmfs\"\n");
